.. image:: https://travis-ci.org/jonashaag/django-addanother.svg?branch=master
    :target: https://travis-ci.org/jonashaag/django-addanother

django-addanother provides you with *add another* buttons for forms outside the Django administration interface. It also provides an optional integration with django-select2_.

See documentation_ for details.

django-addanother has been extracted from django-autocomplete-light v2, after noticing that other apps copied the same code, to ease community maintainance.

.. _django-select2: http://django-select2.readthedocs.org/
.. _documentation: http://django-addanother.readthedocs.org/
